#! /usr/bin/env python

import numpy as np
from CRPCalculator import CRPCalculator

from ase import Atoms
from ase.build import molecule

eV2kJ = 96.4853075

def set_positions_spherical(atoms, x, y, z, r, theta, phi, apply_constraint=True ):
	"""
	Set position of the two atoms with spherical coordinates instead of cartesian coordinates
	"""
	ctheta = np.cos( np.radians( theta ) )
	stheta = np.sin( np.radians( theta ) )
	cphi = np.cos( np.radians( phi ) )
	sphi = np.sin( np.radians( phi ) )

	atoms.set_positions([[x - 0.5 * r * stheta * cphi, y - 0.5 * r * stheta * sphi, z - 0.5 * r * ctheta], [x + 0.5 * r * stheta * cphi, y + 0.5 * r * stheta * sphi, z + 0.5 * r * ctheta]], apply_constraint=apply_constraint)

	return

atoms = molecule('O2')

#lattice vectors for HSE03-1/3X
Cell = np.array(
[[ 0.707106781,    0.000000000,    0.000000000],
[ 0.353553391,    0.612372435,    0.000000000],
[ 0.000000000,    0.000000000,    2.107695648]]
) * 8.044772826
#lattice vectors for MS-RPBEl
Cell = np.array(
[[ 0.707106781,    0.000000000,    0.000000000],
[-0.353553391,    0.612372435,    0.000000000],
[ 0.000000000,    0.000000000,    2.761429154]]
) * 8.090974342
atoms.set_cell( Cell )
atoms.set_pbc( [True, True, True])

#Select the PES
PES = 'Al111_O2_HSE03_13X_C3v'
#PES = 'Al111_O2_MSRPBEl_C3v'
atoms.set_calculator( CRPCalculator(PES) )

# Remember that the direct coordinates are for the entire super cell, and not just a single unit cell (see for example how VASP POSCARs work)
u = 0.
v = 0.
Z = 3.0
r = 1.25
theta = 90.
phi = 0.
pos = np.dot( [u, v, 0.], Cell )
set_positions_spherical( atoms, pos[0], pos[1], Z, r, theta, phi )

print( atoms.get_potential_energy()*eV2kJ )

# Example of how to extract information about the lattice vectors from the CRP
# In principle this could have been used to set up the lattice vectors, but this is not how we implemented it in this example.
from libcrp import crp_python_wrapper
crp_python_wrapper.setup_crp_potential( PES )
print(*crp_python_wrapper.get_potential_info())
